@@ -6,27 +6,27 @@
 #' our package are not real data.
 #' 
 #' The isostopic values for the organisms are assumed to be linearly related to
-#' the one from the environement. The linear function can be parameterized using
+#' the one from the environment. The linear function can be parametrized using
 #' the first argument of the function (\code{calib_fn}). With this function the
 #' user can simulate data for different sites.
 #' 
-#' The number and locations of sites can be controled in two ways. A first
-#' possiblity is to use the argument \code{n_sites}. The sites will then be
+#' The number and locations of sites can be controlled in two ways. A first
+#' possibility is to use the argument \code{n_sites}. The sites will then be
 #' selected randomly among the locations present in the isoscape (argument
-#' \code{isoscape}) provided to this function. An alternative possiblity is to
-#' provide a data frame containing three columns (\code{siteID}, \code{long} and
+#' \code{isoscape}) provided to this function. An alternative possibility is to
+#' provide a data frame containing three columns (\code{site_ID}, \code{long} and
 #' \code{lat}) to input the coordinate of the sampling site manually.
 #' 
-#' Irrespectivelly of how locations are choosen, a random number of observations
+#' Irrespectively of how locations are chosen, a random number of observations
 #' will be drawn, at each site, according to a uniform distribution bounded by 
 #' the values of the argument \code{min_n_samples} and \code{max_n_samples}.
 #' 
-#' From the selected coordinates, the isotope values for the environement are
+#' From the selected coordinates, the isotope values for the environment are
 #' directly extracted from the corresponding point predictions stored in the
 #' isoscape object. No uncertainty is considered during this process. Then the
 #' linear calibration defines the means of the isotope values for the simulated
-#' organims. The actual values is then drawn from a Gaussian distribution
-#' centered around such mean and a variance defined by the residual variance
+#' organisms. The actual values is then drawn from a Gaussian distribution
+#' centred around such mean and a variance defined by the residual variance
 #' (\code{resid_var}) input within the list \code{calib_fn}.
 #' 
 #' @param calib_fn A \var{list} containing the parameter values describing the 
@@ -36,10 +36,10 @@
 #'   
 #' @param isoscape The output of the function \code{\link{isoscape}}
 #' 
-#' @param coordinates An optional \var{data.frame} with columns \code{siteID}, 
+#' @param coordinates An optional \var{data.frame} with columns \code{site_ID}, 
 #' \code{long} and \code{lat}
 #'   
-#' @param elevation_raster A \var{RasterLayer} containing an elevation raster
+#' @param raster A \var{RasterLayer} containing an elevation raster
 #'   
 #' @param n_sites The number of sites from which the simulated organisms
 #'   originate (\var{integer})
@@ -62,24 +62,24 @@
 #' @examples
 #' 
 #' ## The examples below will only be run if sufficient time is allowed
-#' ## You can change that by typing e.g. IsoriX.options(example_maxtime = XX)
+#' ## You can change that by typing e.g. options_IsoriX(example_maxtime = XX)
 #' ## if you want to allow for examples taking up to ca. XX seconds to run
 #' ## (so don't write XX but put a number instead!)
 #' 
-#' if(IsoriX.getOption("example_maxtime") > 30) {
+#' if(getOption_IsoriX("example_maxtime") > 30) {
 #' 
 #' ## We fit the models for Germany
-#' GNIPDataDEagg <- prepdata(data = GNIPDataDE)
+#' GNIPDataDEagg <- prepsources(data = GNIPDataDE)
 #' 
-#' GermanFit <- isofit(iso.data = GNIPDataDEagg)
+#' GermanFit <- isofit(data = GNIPDataDEagg)
 #' 
 #' ## We build the isoscapes
-#' isoscape <- isoscape(elevation.raster = ElevRasterDE, isofit = GermanFit)
+#' GermanScape <- isoscape(raster = ElevRasterDE, isofit = GermanFit)
 #' 
 #' ## We create a simulated dataset with 25 sites and 5 observations per site
 #' Aliens <- create_aliens(calib_fn = list(intercept = 3, slope = 0.5, resid_var = 5),
-#'                         isoscape = isoscape,
-#'                         elevation_raster = ElevRasterDE,
+#'                         isoscape = GermanScape,
+#'                         raster = ElevRasterDE,
 #'                         n_sites = 25,
 #'                         min_n_samples = 5,
 #'                         max_n_samples = 5)
@@ -89,21 +89,20 @@
 #' 
 #' ## We plot the relationship between the environmental isotope values
 #' ## and those from the simulated organisms
-#' plot(tissue.value ~ env.value, data = Aliens, ylab = "Tissue", xlab = "Environment")
+#' plot(sample_value ~ source_value, data = Aliens, ylab = "Tissue", xlab = "Environment")
 #' abline(3, 0.5, col = "blue") ## the true relationship
 #' 
 #' ## We create a simulated dataset with 2 sites imputing coordinates manually
 #' Aliens2 <- create_aliens(calib_fn = list(intercept = 3, slope = 0.5, resid_var = 5),
-#'                          isoscape = isoscape,
-#'                          coordinates = data.frame(siteID = c("Berlin", "Bielefeld"),
+#'                          isoscape = GermanScape,
+#'                          coordinates = data.frame(site_ID = c("Berlin", "Bielefeld"),
 #'                                                   long   = c(13.52134, 8.49914),
 #'                                                   lat    = c(52.50598, 52.03485)),
-#'                          elevation_raster = ElevRasterDE,
-#'                          n_sites = 25,
+#'                          raster = ElevRasterDE,
 #'                          min_n_samples = 5,
 #'                          max_n_samples = 5)
 #'
-#' head(Aliens2)
+#' Aliens2
 #'
 #' }
 #' 
@@ -111,51 +110,50 @@
 create_aliens <- function(calib_fn = list(intercept = 3, slope = 0.5, resid_var = 5),
                           isoscape = NULL,
                           coordinates = NA,
-                          elevation_raster = NULL,
-                          n_sites = 1,
+                          raster = NULL,
+                          n_sites = NA,
                           min_n_samples = 1,
                           max_n_samples = 10) {
   
   ## Complete the arguments
-  .CompleteArgs(create_aliens)  
+  .complete_args(create_aliens)  
   
   ## Choose location for the aliens
-  if(length(coordinates) == 1 && is.na(coordinates)) {
-    LocationData <- data.frame(siteID = sample(1:raster::ncell(isoscape$isoscape$mean), n_sites, replace = FALSE))
-    xy <- raster::xyFromCell(isoscape$isoscape$mean, LocationData$siteID)
+  if (length(coordinates) == 1 && is.na(coordinates)) {
+    LocationData <- data.frame(site_ID = sample(1:raster::ncell(isoscape$isoscape$mean), n_sites, replace = FALSE))
+    xy <- raster::xyFromCell(isoscape$isoscape$mean, LocationData$site_ID)
     LocationData$long <- xy[, "x"]
     LocationData$lat  <- xy[, "y"]
   } else {
-    if(!all(c("siteID", "long", "lat") %in% colnames(coordinates))) {
-      stop("the argument coordinates must contain the columns 'siteID', 'long' and 'lat'")
+    if (!all(c("site_ID", "long", "lat") %in% colnames(coordinates))) {
+      stop("the argument coordinates must contain the columns 'site_ID', 'long' and 'lat'")
     }
-    if(n_sites != nrow(coordinates)) {
+    if (!is.na(n_sites)) {
       warnings("the argument coordinates has been used so the argument 'n_sites' has been ignored")
     }
     LocationData <- coordinates
     xy <- coordinates[, c("long", "lat")]
     n_sites <- nrow(coordinates)
   }
-  LocationData$elev = raster::extract(x = elevation_raster, y = xy)
-  LocationData$n.samples <- round(stats::runif(n = n_sites, min = min_n_samples, max = max_n_samples))
+  LocationData$elev = raster::extract(x = raster, y = xy)
+  LocationData$n_samples <- round(stats::runif(n = n_sites, min = min_n_samples, max = max_n_samples))
   
   ## Predict environmental values at the locations
-  LocationData$env.value <- raster::extract(isoscape$isoscape$mean, xy)
+  LocationData$source_value <- raster::extract(isoscape$isoscapes$mean, xy)
  
   ## Replicate the dataset per animal
-  AlienData <- LocationData[rep(1:nrow(LocationData), times = LocationData$n.samples), ]
-  AlienData$animalID <- factor(paste("Alien", 1:nrow(AlienData), sep = "_"))
+  AlienData <- LocationData[rep(1:nrow(LocationData), times = LocationData$n_samples), ]
+  AlienData$sample_ID <- factor(paste("Alien", 1:nrow(AlienData), sep = "_"))
   
-  ## Turning siteID into a factor
-  AlienData$siteID <- factor(AlienData$siteID)
+  ## Turning site_ID into a factor
+  AlienData$site_ID <- factor(AlienData$site_ID)
   
   ## Predict the tissue value for each animal
-  AlienData$tissue.value <- stats::rnorm(n = nrow(AlienData),
-                                         mean = rep(calib_fn$intercept + LocationData$env.value * calib_fn$slope,
-                                                    times = LocationData$n.samples),
+  AlienData$sample_value <- stats::rnorm(n = nrow(AlienData),
+                                         mean = calib_fn$intercept + AlienData$source_value * calib_fn$slope,
                                          sd = sqrt(calib_fn$resid_var))
   ## Cleanup and return
   rownames(AlienData) <- NULL
-  return(AlienData[, c("siteID", "long", "lat", "elev", "animalID", "env.value", "tissue.value")])
+  return(AlienData[, c("site_ID", "long", "lat", "elev", "sample_ID", "source_value", "sample_value")])
 }
 
