@@ -1,21 +1,12 @@
-#' @rdname IsoriX-defunct
-#' @export
-GetElev <- function(...) {
-  .Defunct("getelev")
-}
-
-
-
-
 #' Download an elevation raster from internet
 #' 
 #' The function \code{getelev} allows for the download of an elevation raster
 #' from internet. It downloads the "Global Multi-resolution Terrain Elevation
-#' Data 2010" from our server. The file was orifginally downloaded from: \cr
+#' Data 2010" from our server. The file was originally downloaded from: \cr
 #' \url{http://topotools.cr.usgs.gov/gmted_viewer/} \cr and converted into a
 #' \var{tif} file by us. The function \code{getelev} uses the generic function
 #' \code{downloadfile} that can also be used to download directly other files.
-#' This raster needs further processing with the function \code{\link{relevate}}
+#' This raster needs further processing with the function \code{\link{prepelev}}
 #' and can then be passed to \code{\link{isoscape}}.
 #' 
 #' If the argument "path" is not provided, the file will be stored in the
@@ -25,9 +16,8 @@ GetElev <- function(...) {
 #' \code{\link{getelev}}. In case of corruption, try downloading the file again,
 #' specifying overwrite = TRUE to overwrite the corrupted file.
 #' 
-#' @aliases getelev downloadfile
 #' @param path A \var{string} indicating where to store the file on the hard
-#' drive
+#' drive (without the file name!)
 #' @param overwrite A \var{logical} indicating if an existing file should be
 #' re-downloaded
 #' @param verbose A \var{logical} indicating whether information about the
@@ -51,19 +41,19 @@ getelev <- function(path = NULL,
                     ) {
 
   ## Define web address and file name
-  address.elev <- "http://62.141.164.7/download/gmted2010_30mn.tif"
-  filename.elev <- "gmted2010_30mn.tif"
+  address_elev <- "http://62.141.164.7/download/gmted2010_30mn.tif"
+  filename_elev <- "gmted2010_30mn.tif"
   
   ## Define md5sum
   ## (created with tools::md5sum("gmted2010_30mn.tif"))
-  md5sum.elev <- "9fbbb014e2f27299137bae21be31ac7c" 
+  md5sum_elev <- "9fbbb014e2f27299137bae21be31ac7c" 
   
   ## Download and check file
-  downloadfile(address = address.elev,
-               filename = filename.elev,
+  downloadfile(address = address_elev,
+               filename = filename_elev,
                path = path,
                overwrite = overwrite,
-               md5sum = md5sum.elev,
+               md5sum = md5sum_elev,
                verbose = verbose
                )
 
@@ -105,19 +95,19 @@ getprecip <- function(path = NULL,
                       ) {
   
   ## Define web address and file name
-  address.precip <- "http://biogeo.ucdavis.edu/data/worldclim/v2.0/tif/base/wc2.0_30s_prec.zip"
-  filename.precip <- "wc2.0_30s_prec.zip"
+  address_precip <- "http://biogeo.ucdavis.edu/data/worldclim/v2.0/tif/base/wc2.0_30s_prec.zip"
+  filename_precip <- "wc2.0_30s_prec.zip"
   
   ## Define md5sum
   ## (created with tools::md5sum("wc2.0_30s_prec.zip"))
-  md5sum.elev <- "afd435222a328efb4ab9487a3fe0b6d4"
+  md5sum_precip <- "afd435222a328efb4ab9487a3fe0b6d4"
   
   ## Download and check file
-  path.to.zip <- downloadfile(address = address.precip,
-                              filename = filename.precip,
+  path_to_zip <- downloadfile(address = address_precip,
+                              filename = filename_precip,
                               path = path,
                               overwrite = overwrite,
-                              md5sum = md5sum.elev,
+                              md5sum = md5sum_precip,
                               verbose = verbose
                               )
   
@@ -125,19 +115,44 @@ getprecip <- function(path = NULL,
   if (verbose > 0) {
     print("unzipping in progress...", quote = FALSE)
   }
-  utils::unzip(path.to.zip, exdir = "wc2.0_30s_prec")
+  outpath <- paste0(path, "wc2.0_30s_prec")
+  utils::unzip(path_to_zip, exdir = outpath)
   
   if (verbose > 0) {
     print("unzipping done!", quote = FALSE)
+    print(paste("The files can be found in the folder", outpath), quote = FALSE)
   }
   
   return(invisible(NULL))
 }
 
-## The following function is a generic function to download files and check 
-## their binary integrity
-## We should write the help and export it.
 
+#' Download files and check their binary integrity
+#'
+#' This function is the internal function used in IsoriX to download the large
+#' files from internet and it could be useful to download anything from within
+#' R. We created this function to make sure that the downloaded files are valid.
+#' Downloads can indeed result in files that are corrupted, so we tweaked the
+#' options to reduce this possibility and the function runs a check if the
+#' signature of the file is provided to the argument `md5sum`.
+#'
+#' @note Users should directly use the function [getelev()] and
+#'   [getprecip()].
+#'
+#' @inheritParams getelev
+#' @param address A \var{string} indicating the address of the file on internet
+#' @param filename A \var{string} indicating the name under which the file must
+#'   be stored
+#' @param md5sum A \var{string} indicating the md5 signature of the valid file
+#'   as created with [tools::md5sum()]
+#'
+#' @return The complete path of the downloaded file (invisibly)
+#'
+#' @export
+#'
+#' @seealso [getelev()], [getprecip()]
+#' 
+#' 
 downloadfile <- function(address = NULL, filename = NULL, path = NULL,
                          overwrite = FALSE, md5sum = NULL, verbose = interactive()
                          ) {
@@ -147,7 +162,7 @@ downloadfile <- function(address = NULL, filename = NULL, path = NULL,
   }
   
   ## Change internet options to display more information
-  opt.ori <- options()$internet.info
+  opt_ori <- options()$internet.info
   if (verbose > 1) options(internet.info = 1)
   
   ## Use current directory if path is missing
@@ -168,19 +183,19 @@ downloadfile <- function(address = NULL, filename = NULL, path = NULL,
   }
   
   ## Conditional file download
-  complete.path <- paste(path, filename, sep = "/")
-  if (file.exists(complete.path) & !overwrite) {
+  complete_path <- paste(path, filename, sep = "/")
+  if (file.exists(complete_path) & !overwrite) {
     message(paste("the file", filename, "is already present in", path,
                   "so it won't be downloaded again unless you set the argument overwrite to TRUE"
                   )
             )
   } else {
-    utils::download.file(address, destfile = complete.path, mode = "wb")
+    utils::download.file(address, destfile = complete_path, mode = "wb")
   }
   
   ## Checking MD5sum
   if (!is.null(md5sum)) {
-    if (tools::md5sum(complete.path) == md5sum) {
+    if (tools::md5sum(complete_path) == md5sum) {
       print("the file seems OK (md5sums do match)", quote = FALSE)
     } else {
       warning("the file seems to be corructed (md5sums do not match). Try to download it again setting the argument overwrite to TRUE.", quote = FALSE)
@@ -193,8 +208,8 @@ downloadfile <- function(address = NULL, filename = NULL, path = NULL,
   }
   
   ## Restore original internet options
-  options(internet.info = opt.ori)
+  options(internet.info = opt_ori)
   
-  return(invisible(complete.path))
+  return(invisible(complete_path))
 }
 
